@@ -13,7 +13,7 @@ use Scalar::Util qw(looks_like_number blessed reftype refaddr);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-03-17'; # DATE
 our $DIST = 'Data-Dump-HTML-Collapsible'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our @EXPORT = qw(dd);
 our @EXPORT_OK = qw(dump);
@@ -199,7 +199,7 @@ sub _dd_or_dump {
         $res = _dump($_[0], '', 0);
     }
     if (@_fixups) {
-        $res = "do { my \$var = $res;\n" . join("", @_fixups) . "\$var }";
+        $res = "do { my \$var = $res;\n" . join("", map {encode_entities $_} @_fixups) . "\$var }";
     }
 
     $res = "<style>details {  margin-left: 1em; } summary { margin-left: -1em; }</style><pre>$res</pre>";
@@ -229,7 +229,7 @@ Data::Dump::HTML::Collapsible - Dump Perl data structures as HTML document with
 
 =head1 VERSION
 
-This document describes version 0.007 of Data::Dump::HTML::Collapsible (from Perl distribution Data-Dump-HTML-Collapsible), released on 2024-03-17.
+This document describes version 0.008 of Data::Dump::HTML::Collapsible (from Perl distribution Data-Dump-HTML-Collapsible), released on 2024-03-17.
 
 =head1 SYNOPSIS
 
